@@ -3,4 +3,4 @@ from shut.commands import shut
 
 
 if __name__ == '__main__':
-  shut()
+  shut()  #: pylint: disable=all
