@@ -23,7 +23,7 @@ from dataclasses import dataclass, field
 import abc
 import os
 import warnings
-from typing import List, Optional
+from typing import TYPE_CHECKING, List, Optional, TypeVar
 
 from .author import Author
 from .changelog import ChangelogConfiguration
@@ -31,6 +31,11 @@ from .release import ReleaseConfiguration
 from .version import Version
 from shut.utils.fs import get_file_in_directory
 
+if TYPE_CHECKING:
+  from shut.renderers.core import Renderer
+
+T_AbstractProjectModel = TypeVar('T_AbstractProjectModel', bound='AbstractProjectModel')
+
 
 @dataclass
 class AbstractProjectModel(abc.ABC):
@@ -105,7 +110,10 @@ class AbstractProjectModel(abc.ABC):
     return get_file_in_directory(
       directory=os.path.dirname(self.filename),
       prefix='LICENSE.',
-      preferred=['LICENSE', 'LICENSE.txt', 'LICENSE.rst', 'LICENSE.md'])
+      preferred=['LICENSE', 'LICENSE.txt', 'LICENSE.rst', 'LICENSE.md'],
+      case_sensitive=False)
 
+  def get_auxiliary_renderers(self: T_AbstractProjectModel) -> List['Renderer[T_AbstractProjectModel]']:
+    return []
 
 from . import Project  # pylint: disable=unused-import
