@@ -25,7 +25,7 @@ import re
 import shlex
 import warnings
 from dataclasses import dataclass, field
-from typing import Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Union, cast
 from typing_extensions import Annotated
 
 from databind.core import annotations as A
@@ -41,6 +41,9 @@ from .requirements import Requirement, RequirementsList
 from ..test import BaseTestDriver
 from .version import Version
 
+if TYPE_CHECKING:
+  from shut.renderers.core import Renderer
+
 
 class PackageError(Exception):
   pass
@@ -199,7 +202,8 @@ class PackageModel(AbstractProjectModel):
     return get_file_in_directory(
       directory=directory,
       prefix='README.',
-      preferred=['README.md', 'README.rst', 'README.txt', 'README'])
+      preferred=['README.md', 'README.rst', 'README.txt', 'README'],
+      case_sensitive=False)
 
   def get_py_typed_file(self) -> Optional[str]:
     if not self.typed:
@@ -248,6 +252,14 @@ class PackageModel(AbstractProjectModel):
     result += self.test_drivers
     return result
 
+  def get_auxiliary_renderers(self) -> List['Renderer[PackageModel]']:
+    from shut.renderers.core import Renderer
+    result = []
+    for driver in self.get_test_drivers():
+      if isinstance(driver, Renderer):
+        result.append(cast('Renderer[PackageModel]', driver))
+    return result
+
   # AbstractProjectModel
 
   def get_name(self) -> str:
